class Collection < ActiveRecord::Base
  include Reviewable
  include Sociable
  include Followable

  has_many :collection_items, as: :collectionable
  has_many :collections, through: :collection_items, source: :collectionable, source_type: 'Collection'
  has_many :learning_objects, through: :collection_items, source: :collectionable, source_type: 'LearningObject'
  has_many :collection_items

  belongs_to :owner, polymorphic: true

  validates :privacy, inclusion: { in: %w(public private), message: "%{value} is not a valid privacy" }

  scope :from_user, ->(user) { where(owner: user) }

  def owner?(candidate)
    owner == candidate
  end

  def private?
    privacy == 'private'
  end
end
