class Orientdb::LearningObject
  include ActiveModel::Model
  include RepositoriesProxy
  include OrientDbSerializable
  include Metadatable

  attr_accessor :id, :id_dspace, :rid, :name, :author, :description,
                :published_at, :thumbnail, :created_at, :last_modified,
                :type, :metadata, :score, :school_level, :language,
                :source, :license, :keywords, :attachments

  #not implemented yet
  attr_accessor :grade_level

  # associations
  attr_accessor :likes, :views, :downloads, :subjects, :attributes, :publisher

  # flags
  attr_accessor :status

  validates_presence_of :name, :created_at, :type

  def initialize(params={})
    super(params.merge(defaults) { |key, oldval, newval| oldval.blank? ? newval : oldval })
  end

  def retrievelink
    "#{DspaceService.link}/rest#{default_attachment.retrieve_link}"
  end

  def default_attachment
    return attachments.find { |a|  a.bundle_name == 'ORIGINAL' } unless attachments.blank?
    ::LearningObject::Attachment.new
  end

  def collections
    collection_repository.find_by_learning_object self
  end

  def categories
    get_metadata_value_of 'dc.subject.category'
  end

  ## social actions
  def like(user)
    learning_object_repository.like user, self
  end

  def liked?(user)
    learning_object_repository.liked? user, self
  end

  def dislike(user)
    learning_object_repository.dislike user, self
  end

  def download(user)
    learning_object_repository.download user, self
  end
  ## end social actions

  ## metadata methods
  def get_metadata_value_of key
    get_metadata_values_of(key).first
  end

  def likes
    learning_object_repository.count('Likes', self)
  end

  def views
    learning_object_repository.count('Views', self)
  end

  def to_orientdb_hash
    bitstreams = attachments.map { |attachment| attachment.to_orientdb_hash }
    super.merge({'bitstreams' => bitstreams})
  end

  def excluded_orientdb_properties
    ['likes', 'views', 'downloads', 'subjects', 'attributes', 'publisher', 'attachments']
  end

  private

  def defaults
    {
        downloads: 0,
        score: 0,
        status: 'active',
        attachments: [],
        attributes: [],
        subjects: [],
        metadata: [],
        created_at: DateTime.now.strftime("%Y-%m-%d %H:%M:%S"),
        last_modified: DateTime.now.strftime("%Y-%m-%d %H:%M:%S")
    }
  end

end
