/*
 *  This file is part of Autocomplete-Server
 *
 *  Autocomplete-Server is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Foobar is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#ifndef SERVER_HPP
#define SERVER_HPP



/*===============================  INCLUDES  ================================*/

#include <microhttpd.h>
#include "task.hpp"

/*---------------------------------------------------------------------------*/



/*============================  EmbeddedServer  =============================
 * This classe implements a microserver http using the library libmicrohttpd 
 * created by GNU. See more in https://www.gnu.org/software/libmicrohttpd/
 * 
 * The server is important because, it is always in memory, then there is not
 * cust by to load the dictionary. And the microserver create a thread of the
 * function ahc_echo, which call the class Task. In the task is execute the
 * function for found the words close of the query
 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */


class EmbeddedServer {
  private:
	struct MHD_Daemon* daemon;
	Task task;

  public:
	/*  @brief Constructor MicroServer
		@param filename The filename of dictionary
		@param port     the port of server, by default 4242
	*/
	EmbeddedServer(std::string filename, int port=4242);
	~EmbeddedServer();

	/*  @brief Configure for send a file */
	struct MHD_Response* sendFile(std::string filename);

	/*  @brief All connection creates a thread and execute this static
	    function. The object pointer of EmbeddedServer is in void *_server
	*/
	static int ahc_echo(
		void* _server,
		struct MHD_Connection * connection,
		const char*  url,
		const char*  method,
		const char*  version,
		const char*  upload_data,
		size_t*      upload_data_size,
		void**       ptr
	);

};


/*---------------------------------------------------------------------------*/



#endif
