namespace :fakedata do
  desc "Fake data generation tasks"

  task generate_users: :environment do
    desc "Generate fake Users"

    include RepositoriesProxy

    total_new_users = 50

    (1..total_new_users).each do |i|
      user = User.new(
              :name => "User#{i}",
              :email => "user#{i}@inf.ufpr.br",
              :password => "1234567890",
              :password_confirmation => "1234567890"
            )
      user.save
    end
  end

  task generate_data: :environment do
    desc "Generate fake user Likes/Views data"

    include RepositoriesProxy

    # Quantity of items fetched on each iteration
    limit = 100

    # Start point from where items will be fetched
    offset = 0

    users = User.all

    loop do

      begin
        # Get items from dspace (from offset to offset+limit)
        learning_objects = learning_object_repository.all_from_offset_to_limit(limit,offset)
      rescue
        # Sleeps for a while to wait database's recovery
        sleep(30.seconds)
        # Goes to next iteration to retry
        next
      else
        # Terminate loop if there are no more items to import
        break if learning_objects.empty?

        # Increment offset, to get new items on next iteration
        offset = offset + limit

        learning_objects.each do |lo|

          users_views = []
          users_likes = []

          users.each do |user|
            # Randomize "Views"
            if random_check(30)
              users_views << user.  id
              # Randomize "Likes"
              if random_check(70)
                users_likes << user.id
              end
            end
          end

          MassiveViewsCreatorWorker.perform_async(lo.id, users_views)
          MassiveLikesCreatorWorker.perform_async(lo.id, users_likes)

        end

      end

    end

  end

  private

  def random_check(threshold)
    if rand(1..100) <= threshold
      return true
    else
      return false
    end
  end

end
